diff --git a/src/vs/workbench/parts/debug/browser/debugEditorModelManager.ts b/src/vs/workbench/parts/debug/browser/debugEditorModelManager.ts
index ecfcac5c456..7a55ae49eef 100644
--- a/src/vs/workbench/parts/debug/browser/debugEditorModelManager.ts
+++ b/src/vs/workbench/parts/debug/browser/debugEditorModelManager.ts
@@ -294,7 +294,7 @@ export class DebugEditorModelManager implements wbext.IWorkbenchContribution {
stickiness: editorcommon.TrackedRangeStickiness.NeverGrowsWhenTypingAtEdges
};
- // We need a seperate decoration for glyph margin, since we do not want it on each line of a multi line statement.
+ // We need a separate decoration for glyph margin, since we do not want it on each line of a multi line statement.
private static TOP_STACK_FRAME_MARGIN: editorcommon.IModelDecorationOptions = {
glyphMarginClassName: 'debug-top-stack-frame-glyph',
stickiness: editorcommon.TrackedRangeStickiness.NeverGrowsWhenTypingAtEdges
diff --git a/src/vs/workbench/parts/debug/browser/debugHoverWidget.ts b/src/vs/workbench/parts/debug/browser/debugHoverWidget.ts
index d97cb32757b..27b841e9da6 100644
--- a/src/vs/workbench/parts/debug/browser/debugHoverWidget.ts
+++ b/src/vs/workbench/parts/debug/browser/debugHoverWidget.ts
@@ -47,8 +47,8 @@ export class DebugHoverWidget implements editorbrowser.IContentWidget {
const pos = range.getStartPosition();
const wordAtPosition = this.editor.getModel().getWordAtPosition(pos);
const hoveringOver = wordAtPosition ? wordAtPosition.word : null;
- const focussedStackFrame = this.debugService.getViewModel().getFocusedStackFrame();
- if (!hoveringOver || !focussedStackFrame || (this.isVisible && hoveringOver === this.lastHoveringOver)) {
+ const focusedStackFrame = this.debugService.getViewModel().getFocusedStackFrame();
+ if (!hoveringOver || !focusedStackFrame || (this.isVisible && hoveringOver === this.lastHoveringOver)) {
return;
}
@@ -60,7 +60,7 @@ export class DebugHoverWidget implements editorbrowser.IContentWidget {
namesToFind[0] = namesToFind[0].substring(namesToFind[0].lastIndexOf(' ') + 1);
const variables: debug.IExpression[] = [];
- focussedStackFrame.getScopes(this.debugService).done(scopes => {
+ focusedStackFrame.getScopes(this.debugService).done(scopes => {
// flatten out scopes lists
return scopes.reduce((accum, scopes) => { return accum.concat(scopes); }, [])
diff --git a/src/vs/workbench/parts/debug/common/debugModel.ts b/src/vs/workbench/parts/debug/common/debugModel.ts
index 002a98d3e3c..61f57fc6b2c 100644
--- a/src/vs/workbench/parts/debug/common/debugModel.ts
+++ b/src/vs/workbench/parts/debug/common/debugModel.ts
@@ -555,7 +555,7 @@ export class Model extends ee.EventEmitter implements debug.IModel {
this.threads[data.threadId].callStack = data.callStack.map(
(rsf, level) => {
if (!rsf) {
- return new StackFrame(data.threadId, 0, debug.Source.fromUri(uri.parse('unknown')), nls.localize('unkownStack', "Unknown stack location"), undefined, undefined);
+ return new StackFrame(data.threadId, 0, debug.Source.fromUri(uri.parse('unknown')), nls.localize('unknownStack', "Unknown stack location"), undefined, undefined);
}
return new StackFrame(data.threadId, rsf.id, rsf.source ? debug.Source.fromRawSource(rsf.source) : debug.Source.fromUri(uri.parse('unknown')), rsf.name, rsf.line, rsf.column);
diff --git a/src/vs/workbench/parts/debug/common/debugProtocol.d.ts b/src/vs/workbench/parts/debug/common/debugProtocol.d.ts
index c3ec89074f0..9ae5973e25b 100644
--- a/src/vs/workbench/parts/debug/common/debugProtocol.d.ts
+++ b/src/vs/workbench/parts/debug/common/debugProtocol.d.ts
@@ -65,7 +65,7 @@ declare module DebugProtocol {
reason: string;
/** The thread which was stopped. */
threadId?: number;
- /** Additonal information. E.g. if reason is 'exception', text contains the exception name. */
+ /** Additional information. E.g. if reason is 'exception', text contains the exception name. */
text?: string;
};
}
diff --git a/src/vs/workbench/parts/emmet/node/editorAccessor.ts b/src/vs/workbench/parts/emmet/node/editorAccessor.ts
index 01a37311fa7..fc97c72cb8d 100644
--- a/src/vs/workbench/parts/emmet/node/editorAccessor.ts
+++ b/src/vs/workbench/parts/emmet/node/editorAccessor.ts
@@ -83,7 +83,7 @@ export class EditorAccessor implements emmet.Editor {
}
}
- // shift colum by +1 since they are 1 based
+ // shift column by +1 since they are 1 based
let range = new Range(startPosition.lineNumber, startPosition.column + 1, endPosition.lineNumber, endPosition.column + 1);
let deletePreviousChars = 0;
diff --git a/src/vs/workbench/parts/emmet/node/emmet.d.ts b/src/vs/workbench/parts/emmet/node/emmet.d.ts
index 71cf3eb906e..5a5380d64b3 100644
--- a/src/vs/workbench/parts/emmet/node/emmet.d.ts
+++ b/src/vs/workbench/parts/emmet/node/emmet.d.ts
@@ -25,7 +25,7 @@ declare module 'emmet' {
/**
* Creates selection from start to end character
- * indexes. If end is ommited, this method should place caret
+ * indexes. If end is omitted, this method should place caret
* and start index
* @param {Number} start
* @param {Number} [end]
@@ -133,4 +133,4 @@ declare module 'emmet' {
*/
export function run(action: string, editor: Editor): boolean;
-}
\ No newline at end of file
+}
diff --git a/src/vs/workbench/parts/files/browser/editors/textFileEditorModel.ts b/src/vs/workbench/parts/files/browser/editors/textFileEditorModel.ts
index 76558cad4a4..c6abef3c064 100644
--- a/src/vs/workbench/parts/files/browser/editors/textFileEditorModel.ts
+++ b/src/vs/workbench/parts/files/browser/editors/textFileEditorModel.ts
@@ -703,7 +703,7 @@ export class TextFileEditorModel extends BaseTextEditorModel implements IEncodin
}
if (!this.preferredEncoding && this.contentEncoding === encoding) {
- return false; // also return if we dont have a preferred encoding but the content encoding is already the same
+ return false; // also return if we don't have a preferred encoding but the content encoding is already the same
}
return true;
diff --git a/src/vs/workbench/parts/files/browser/fileActions.ts b/src/vs/workbench/parts/files/browser/fileActions.ts
index d518ba270e4..ef61435ce44 100644
--- a/src/vs/workbench/parts/files/browser/fileActions.ts
+++ b/src/vs/workbench/parts/files/browser/fileActions.ts
@@ -288,7 +288,7 @@ export abstract class BaseRenameAction extends BaseFileAction {
name = getWellFormedFileName(name);
let existingName = getWellFormedFileName(this.element.name);
- // Return early if name is invalid or didnt change
+ // Return early if name is invalid or didn't change
if (name === existingName || this.validateFileName(this.element.parent, name)) {
return Promise.as(null);
}
diff --git a/src/vs/workbench/parts/files/browser/fileTracker.ts b/src/vs/workbench/parts/files/browser/fileTracker.ts
index bbfa8325961..7b5a95fada3 100644
--- a/src/vs/workbench/parts/files/browser/fileTracker.ts
+++ b/src/vs/workbench/parts/files/browser/fileTracker.ts
@@ -87,7 +87,7 @@ export class FileTracker implements IWorkbenchContribution {
this.emitInputStateChangeEvent(e.getAfter().resource);
if (!this.contextService.isAutoSaveEnabled()) {
- this.updateActivityBadge(); // no indication needed when auto save is turned off and we didnt show dirty
+ this.updateActivityBadge(); // no indication needed when auto save is turned off and we didn't show dirty
}
}
@@ -182,7 +182,7 @@ export class FileTracker implements IWorkbenchContribution {
this.handleMovedFileInVisibleEditors(before ? before.resource : null, after ? after.resource : null, after ? after.mime : null);
}
- // Dispose all known inputs pased on resource
+ // Dispose all known inputs passed on resource
let oldFile = e.getBefore();
if ((e.gotMoved() || e.gotDeleted())) {
this.disposeAll(oldFile.resource, this.quickOpenService.getEditorHistory());
diff --git a/src/vs/workbench/parts/files/browser/files.contribution.ts b/src/vs/workbench/parts/files/browser/files.contribution.ts
index b0f4da1a033..6d6d295e59d 100644
--- a/src/vs/workbench/parts/files/browser/files.contribution.ts
+++ b/src/vs/workbench/parts/files/browser/files.contribution.ts
@@ -75,7 +75,7 @@ let openViewletKb: IKeybindings = {
// Register file editors
(Registry.as(EditorExtensions.Editors)).registerEditor(
new FileEditorDescriptor(
- TextFileEditor.ID, // explicit dependency because we dont want these editors lazy loaded
+ TextFileEditor.ID, // explicit dependency because we don't want these editors lazy loaded
nls.localize('textFileEditor', "Text File Editor"),
'vs/workbench/parts/files/browser/editors/textFileEditor',
'TextFileEditor',
@@ -95,7 +95,7 @@ let openViewletKb: IKeybindings = {
(Registry.as(EditorExtensions.Editors)).registerEditor(
new FileEditorDescriptor(
- BinaryFileEditor.ID, // explicit dependency because we dont want these editors lazy loaded
+ BinaryFileEditor.ID, // explicit dependency because we don't want these editors lazy loaded
nls.localize('binaryFileEditor', "Binary File Editor"),
'vs/workbench/parts/files/browser/editors/binaryFileEditor',
'BinaryFileEditor',
diff --git a/src/vs/workbench/parts/files/browser/views/explorerViewer.ts b/src/vs/workbench/parts/files/browser/views/explorerViewer.ts
index cdc4ec22f3e..0753d3dc286 100644
--- a/src/vs/workbench/parts/files/browser/views/explorerViewer.ts
+++ b/src/vs/workbench/parts/files/browser/views/explorerViewer.ts
@@ -84,7 +84,7 @@ export class FileDataSource implements Tree.IDataSource {
// Convert to view model
let modelDirStat = FileStat.create(dirStat);
- // Add childs to folder
+ // Add children to folder
for (let i = 0; i < modelDirStat.children.length; i++) {
stat.addChild(modelDirStat.children[i]);
}
diff --git a/src/vs/workbench/parts/files/browser/views/workingFilesView.ts b/src/vs/workbench/parts/files/browser/views/workingFilesView.ts
index d7fe22657fe..2945647ab47 100644
--- a/src/vs/workbench/parts/files/browser/views/workingFilesView.ts
+++ b/src/vs/workbench/parts/files/browser/views/workingFilesView.ts
@@ -150,7 +150,7 @@ export class WorkingFilesView extends AdaptiveCollapsibleViewletView {
private onTextFileDirty(e: LocalFileChangeEvent): void {
if (!this.contextService.isAutoSaveEnabled()) {
- this.updateDirtyIndicator(); // no indication needed when auto save is turned off and we didnt show dirty
+ this.updateDirtyIndicator(); // no indication needed when auto save is turned off and we didn't show dirty
}
}
diff --git a/src/vs/workbench/parts/files/browser/views/workingFilesViewer.ts b/src/vs/workbench/parts/files/browser/views/workingFilesViewer.ts
index 4d6d820b592..9cac592301f 100644
--- a/src/vs/workbench/parts/files/browser/views/workingFilesViewer.ts
+++ b/src/vs/workbench/parts/files/browser/views/workingFilesViewer.ts
@@ -134,7 +134,7 @@ export class WorkingFilesActionProvider extends ContributableActionProvider {
return element instanceof WorkingFileEntry || super.hasActions(tree, element);
}
- // we dont call into super here because we put only one primary action to the left (Remove/Dirty Indicator)
+ // we don't call into super here because we put only one primary action to the left (Remove/Dirty Indicator)
public getActions(tree: tree.ITree, element: WorkingFileEntry): TPromise {
let actions: actions.IAction[] = [];
diff --git a/src/vs/workbench/parts/files/browser/workingFilesModel.ts b/src/vs/workbench/parts/files/browser/workingFilesModel.ts
index a3401d6b595..48bc1360730 100644
--- a/src/vs/workbench/parts/files/browser/workingFilesModel.ts
+++ b/src/vs/workbench/parts/files/browser/workingFilesModel.ts
@@ -87,7 +87,7 @@ export class WorkingFilesModel implements filesCommon.IWorkingFilesModel {
private onTextFileDirty(e: filesCommon.LocalFileChangeEvent): void {
if (!this.contextService.isAutoSaveEnabled()) {
- this.updateDirtyState(e.getAfter().resource, true); // no indication needed when auto save is turned off and we didnt show dirty
+ this.updateDirtyState(e.getAfter().resource, true); // no indication needed when auto save is turned off and we didn't show dirty
} else {
this.addEntry(e.getAfter().resource);
}
diff --git a/src/vs/workbench/parts/files/common/files.ts b/src/vs/workbench/parts/files/common/files.ts
index 5ccff56b211..9060c91d3e7 100644
--- a/src/vs/workbench/parts/files/common/files.ts
+++ b/src/vs/workbench/parts/files/common/files.ts
@@ -294,7 +294,7 @@ export interface ITextFileService extends IDisposable {
isDirty(resource?: URI): boolean;
/**
- * Returs all resources that are currently dirty matching the provided resource or all dirty resources.
+ * Returns all resources that are currently dirty matching the provided resource or all dirty resources.
*
* @param resource the resource to check for being dirty. If it is not specified, will check for
* all dirty resources.
@@ -342,7 +342,7 @@ export interface ITextFileService extends IDisposable {
revertAll(resources?: URI[], force?: boolean): TPromise;
/**
- * Brings up the confirm dialog to either save, dont save or cancel.
+ * Brings up the confirm dialog to either save, don't save or cancel.
*
* @param resource the resource of the file to ask for confirmation.
*/
diff --git a/src/vs/workbench/parts/files/electron-browser/electronFileTracker.ts b/src/vs/workbench/parts/files/electron-browser/electronFileTracker.ts
index f7460d2fd33..4fc1ba4f9a6 100644
--- a/src/vs/workbench/parts/files/electron-browser/electronFileTracker.ts
+++ b/src/vs/workbench/parts/files/electron-browser/electronFileTracker.ts
@@ -161,7 +161,7 @@ export class FileTracker implements IWorkbenchContribution {
private onTextFileDirty(e: LocalFileChangeEvent): void {
if (!this.contextService.isAutoSaveEnabled() && !this.isDocumentedEdited) {
- this.updateDocumentEdited(); // no indication needed when auto save is turned off and we didnt show dirty
+ this.updateDocumentEdited(); // no indication needed when auto save is turned off and we didn't show dirty
}
}
diff --git a/src/vs/workbench/parts/files/electron-browser/textFileServices.ts b/src/vs/workbench/parts/files/electron-browser/textFileServices.ts
index 7179263c8d4..823ebb6e3c4 100644
--- a/src/vs/workbench/parts/files/electron-browser/textFileServices.ts
+++ b/src/vs/workbench/parts/files/electron-browser/textFileServices.ts
@@ -233,7 +233,7 @@ export class TextFileService extends BrowserTextFileService {
if (untitled) {
let targetPath: string;
- // Untitled with associated file path dont need to prompt
+ // Untitled with associated file path don't need to prompt
if (this.untitledEditorService.hasAssociatedFilePath(untitled.getResource())) {
targetPath = untitled.getResource().fsPath;
}
diff --git a/src/vs/workbench/parts/git/browser/gitActions.ts b/src/vs/workbench/parts/git/browser/gitActions.ts
index 4f633bb51c3..640854afd15 100644
--- a/src/vs/workbench/parts/git/browser/gitActions.ts
+++ b/src/vs/workbench/parts/git/browser/gitActions.ts
@@ -406,7 +406,7 @@ export abstract class BaseUndoAction extends GitAction {
});
});
}).then(null, (errors: any[]): Promise => {
- console.error('One or more errors occured', errors);
+ console.error('One or more errors occurred', errors);
return Promise.wrapError(errors[0]);
});
}
diff --git a/src/vs/workbench/parts/git/common/stageRanges.ts b/src/vs/workbench/parts/git/common/stageRanges.ts
index 50720021c56..e34752e4a90 100644
--- a/src/vs/workbench/parts/git/common/stageRanges.ts
+++ b/src/vs/workbench/parts/git/common/stageRanges.ts
@@ -69,7 +69,7 @@ export function intersectChangeAndSelection(change:editorcommon.IChange, selecti
}
/**
- * Returns all selected changes (there can be mulitple selections due to mulitple cursors).
+ * Returns all selected changes (there can be multiple selections due to multiple cursors).
* If a change is partially selected, the selected part of the change will be returned.
*/
export function getSelectedChanges(changes:editorcommon.IChange[], selections:editorcommon.IEditorSelection[]):editorcommon.IChange[] {
diff --git a/src/vs/workbench/parts/git/test/common/stageRanges.test.ts b/src/vs/workbench/parts/git/test/common/stageRanges.test.ts
index bbaccf8a59c..0220b1c9666 100644
--- a/src/vs/workbench/parts/git/test/common/stageRanges.test.ts
+++ b/src/vs/workbench/parts/git/test/common/stageRanges.test.ts
@@ -87,7 +87,7 @@ suite('Git - Stage ranges', () => {
changesEqual(result, expected);
});
- test('Get selected changes test - mulitple changes selected with one selection', () => {
+ test('Get selected changes test - multiple changes selected with one selection', () => {
var selections: IEditorSelection[] = [];
selections.push(Selection.createSelection(2, 7, 7, 1));
var changes: IChange[] = [];
@@ -119,7 +119,7 @@ suite('Git - Stage ranges', () => {
changesEqual(result, expected);
});
- test('Get selected changes test - mulitple changes partially selected with multiple selections', () => {
+ test('Get selected changes test - multiple changes partially selected with multiple selections', () => {
var selections: IEditorSelection[] = [];
selections.push(Selection.createSelection(3, 1, 9, 5), Selection.createSelection(115, 2, 129, 1));
var changes: IChange[] = [];
@@ -130,7 +130,7 @@ suite('Git - Stage ranges', () => {
changesEqual(result, expected);
});
- test('Get selected changes test - mulitple changes selected with multiple selections. Multiple changes not selected', () => {
+ test('Get selected changes test - multiple changes selected with multiple selections. Multiple changes not selected', () => {
var selections: IEditorSelection[] = [];
selections.push(Selection.createSelection(33, 11, 79, 15), Selection.createSelection(155, 21, 189, 11));
var changes: IChange[] = [];
diff --git a/src/vs/workbench/parts/lib/test/node/systemVariables.test.ts b/src/vs/workbench/parts/lib/test/node/systemVariables.test.ts
index 8cb9b181347..debae512745 100644
--- a/src/vs/workbench/parts/lib/test/node/systemVariables.test.ts
+++ b/src/vs/workbench/parts/lib/test/node/systemVariables.test.ts
@@ -11,7 +11,7 @@ import * as Platform from 'vs/base/common/platform';
import { SystemVariables } from 'vs/workbench/parts/lib/node/systemVariables';
suite('SystemVariables tests', () => {
- test('SytemVariables: subsitute one', () => {
+ test('SystemVariables: substitute one', () => {
let systemVariables: SystemVariables = new SystemVariables(null, null, URI.parse('file:///VSCode/workspaceLocation'));
if (Platform.isWindows) {
assert.strictEqual(systemVariables.resolve('abc ${workspaceRoot} xyz'), 'abc \\VSCode\\workspaceLocation xyz');
@@ -20,7 +20,7 @@ suite('SystemVariables tests', () => {
}
});
- test('SytemVariables: subsitute many', () => {
+ test('SystemVariables: substitute many', () => {
let systemVariables: SystemVariables = new SystemVariables(null, null, URI.parse('file:///VSCode/workspaceLocation'));
if (Platform.isWindows) {
assert.strictEqual(systemVariables.resolve('${workspaceRoot} - ${workspaceRoot}'), '\\VSCode\\workspaceLocation - \\VSCode\\workspaceLocation');
diff --git a/src/vs/workbench/parts/output/browser/outputActions.ts b/src/vs/workbench/parts/output/browser/outputActions.ts
index 2e9b316845f..b07c6695955 100644
--- a/src/vs/workbench/parts/output/browser/outputActions.ts
+++ b/src/vs/workbench/parts/output/browser/outputActions.ts
@@ -63,7 +63,7 @@ export class GlobalShowOutputAction extends Action {
channelToOpen = channels[0].getChannel();
}
- // Fallback to any contributed channel otherwise if we dont have history
+ // Fallback to any contributed channel otherwise if we don't have history
else {
channelToOpen = (Registry.as(Extensions.OutputChannels)).getChannels()[0];
}
@@ -191,7 +191,7 @@ export class SwitchOutputActionItem extends SelectActionItem {
super(null, action, SwitchOutputActionItem.getChannels(outputService, input), SwitchOutputActionItem.getChannels(outputService, input).indexOf(input.getChannel()));
this.input = input;
-
+
this.outputService.onOutputChannel.add(this.onOutputChannel, this);
}
diff --git a/src/vs/workbench/parts/search/browser/openAnythingHandler.ts b/src/vs/workbench/parts/search/browser/openAnythingHandler.ts
index 13fe0319a9c..8b04c1fcc1c 100644
--- a/src/vs/workbench/parts/search/browser/openAnythingHandler.ts
+++ b/src/vs/workbench/parts/search/browser/openAnythingHandler.ts
@@ -29,7 +29,7 @@ export class OpenAnythingHandler extends QuickOpenHandler {
private static SYMBOL_SEARCH_INITIAL_TIMEOUT = 500; // Ignore symbol search after a timeout to not block search results
private static SYMBOL_SEARCH_SUBSEQUENT_TIMEOUT = 100;
- private static SEARCH_DELAY = 100; // This delay acommodates for the user typing a word and then stops typing to start searching
+ private static SEARCH_DELAY = 100; // This delay accommodates for the user typing a word and then stops typing to start searching
private openSymbolHandler: _OpenSymbolHandler;
private openFileHandler: OpenFileHandler;
diff --git a/src/vs/workbench/parts/search/browser/openFileHandler.ts b/src/vs/workbench/parts/search/browser/openFileHandler.ts
index 042b49c4573..9c3287e7477 100644
--- a/src/vs/workbench/parts/search/browser/openFileHandler.ts
+++ b/src/vs/workbench/parts/search/browser/openFileHandler.ts
@@ -84,7 +84,7 @@ export class FileEntry extends EditorQuickOpenEntry {
export class OpenFileHandler extends QuickOpenHandler {
- private static SEARCH_DELAY = 500; // This delay acommodates for the user typing a word and then stops typing to start searching
+ private static SEARCH_DELAY = 500; // This delay accommodates for the user typing a word and then stops typing to start searching
private queryBuilder: QueryBuilder;
private delayer: ThrottledDelayer;
diff --git a/src/vs/workbench/parts/search/browser/openSymbolHandler.ts b/src/vs/workbench/parts/search/browser/openSymbolHandler.ts
index da7a4ec68f7..9ba6d686ae4 100644
--- a/src/vs/workbench/parts/search/browser/openSymbolHandler.ts
+++ b/src/vs/workbench/parts/search/browser/openSymbolHandler.ts
@@ -90,7 +90,7 @@ class SymbolEntry extends EditorQuickOpenEntry {
export class OpenSymbolHandler extends QuickOpenHandler {
private static SUPPORTED_OPEN_TYPES = ['class', 'interface', 'enum', 'function', 'method'];
- private static SEARCH_DELAY = 500; // This delay acommodates for the user typing a word and then stops typing to start searching
+ private static SEARCH_DELAY = 500; // This delay accommodates for the user typing a word and then stops typing to start searching
private delayer: ThrottledDelayer;
private isStandalone: boolean;
diff --git a/src/vs/workbench/parts/search/browser/searchViewlet.ts b/src/vs/workbench/parts/search/browser/searchViewlet.ts
index 27d68d45479..5cdd1f5f4ef 100644
--- a/src/vs/workbench/parts/search/browser/searchViewlet.ts
+++ b/src/vs/workbench/parts/search/browser/searchViewlet.ts
@@ -929,7 +929,7 @@ export class SearchViewlet extends Viewlet {
this.viewModel.toggleHighlights(visible);
}
- // Open focussed element from results in case the editor area is otherwise empty
+ // Open focused element from results in case the editor area is otherwise empty
if (visible && !this.editorService.getActiveEditorInput()) {
let focus = this.tree.getFocus();
if (focus) {
diff --git a/src/vs/workbench/parts/tasks/common/problemCollectors.ts b/src/vs/workbench/parts/tasks/common/problemCollectors.ts
index 95c7e86b725..bc2db5ae711 100644
--- a/src/vs/workbench/parts/tasks/common/problemCollectors.ts
+++ b/src/vs/workbench/parts/tasks/common/problemCollectors.ts
@@ -204,12 +204,12 @@ export class StartStopProblemCollector extends AbstractProblemCollector implemen
this.currentResource = resource;
this.currentResourceAsString = resourceAsString;
}
- let markerDatas = this.markers[owner];
- if (!markerDatas) {
- markerDatas = [];
- this.markers[owner] = markerDatas;
+ let markerData = this.markers[owner];
+ if (!markerData) {
+ markerData = [];
+ this.markers[owner] = markerData;
}
- markerDatas.push(markerMatch.marker);
+ markerData.push(markerMatch.marker);
} else {
this.reportedResourcesWithMarkers[owner][resourceAsString] = resource;
}
@@ -316,12 +316,12 @@ export class WatchingProblemCollector extends AbstractProblemCollector implement
this.currentResource = resource;
this.currentResourceAsString = resourceAsString;
}
- let markerDatas = this.markers[owner];
- if (!markerDatas) {
- markerDatas = [];
- this.markers[owner] = markerDatas;
+ let markerData = this.markers[owner];
+ if (!markerData) {
+ markerData = [];
+ this.markers[owner] = markerData;
}
- markerDatas.push(markerMatch.marker);
+ markerData.push(markerMatch.marker);
} else {
this.removeResourceToClean(owner, resourceAsString);
}
diff --git a/src/vs/workbench/parts/tasks/electron-browser/task.contribution.ts b/src/vs/workbench/parts/tasks/electron-browser/task.contribution.ts
index 818660543da..83c0dd24ae4 100644
--- a/src/vs/workbench/parts/tasks/electron-browser/task.contribution.ts
+++ b/src/vs/workbench/parts/tasks/electron-browser/task.contribution.ts
@@ -1025,7 +1025,7 @@ if (Env.enableTasks) {
'isShellCommand': {
'type': 'boolean',
'default': true,
- 'description': nls.localize('JsonSchema.shell', 'Specifies whether the command is a shell command or an external programm. Defaults to false if omitted.')
+ 'description': nls.localize('JsonSchema.shell', 'Specifies whether the command is a shell command or an external program. Defaults to false if omitted.')
},
'args': {
'type': 'array',
@@ -1053,7 +1053,7 @@ if (Env.enableTasks) {
},
'showOutput': {
'$ref': '#/definitions/showOutputType',
- 'description': nls.localize('JsonSchema.showOuput', 'Controls whether the output of the running task is shown or not. If omitted \'always\' is used.')
+ 'description': nls.localize('JsonSchema.showOutput', 'Controls whether the output of the running task is shown or not. If omitted \'always\' is used.')
},
'isWatching': {
'type': 'boolean',
@@ -1111,7 +1111,7 @@ if (Env.enableTasks) {
},
'showOutput': {
'$ref': '#/definitions/showOutputType',
- 'description': nls.localize('JsonSchema.tasks.showOuput', 'Controls whether the output of the running task is shown or not. If omitted the globally defined value is used.')
+ 'description': nls.localize('JsonSchema.tasks.showOutput', 'Controls whether the output of the running task is shown or not. If omitted the globally defined value is used.')
},
'echoCommand': {
'type': 'boolean',
diff --git a/src/vs/workbench/parts/files/browser/views/explorerView.ts b/src/vs/workbench/parts/files/browser/views/explorerView.ts
index 48430dc8461..50d1b00c12c 100644
--- a/src/vs/workbench/parts/files/browser/views/explorerView.ts
+++ b/src/vs/workbench/parts/files/browser/views/explorerView.ts
@@ -150,7 +150,7 @@ export class ExplorerView extends CollapsibleViewletView {
// During workbench startup, the editor area might restore more than one editor from a previous
// session. When this happens there might be editor input changing events for side editors that
// dont have focus. In these cases we do not adjust explorer selection for non-focussed editors
// because we only want to react for the editor that has focus.
if (!this.partService.isCreated() && e.editorOptions && e.editorOptions.preserveFocus) {
return;
@@ -198,10 +198,10 @@ export class ExplorerView extends CollapsibleViewletView {
public focus(): void {
super.focus();
// Open the focussed element in the editor if there is currently no file opened
let input = this.editorService.getActiveEditorInput();
if (!input || !(input instanceof FileEditorInput)) {
- this.openFocussedElement();
+ this.openFocusedElement();
}
}
@@ -247,13 +247,13 @@ export class ExplorerView extends CollapsibleViewletView {
// Otherwise restore last used file: By Explorer selection
return refreshPromise.then(() => {
- this.openFocussedElement();
+ this.openFocusedElement();
});
}
});
}
- private openFocussedElement(): boolean {
+ private openFocusedElement(): boolean {
let stat: FileStat = this.explorerViewer.getFocus();
if (stat && !stat.isDirectory) {
let editorInput = this.instantiationService.createInstance(FileEditorInput, stat.resource, stat.mime, void 0);
@@ -150,7 +150,7 @@ export class ExplorerView extends CollapsibleViewletView {
// During workbench startup, the editor area might restore more than one editor from a previous
// session. When this happens there might be editor input changing events for side editors that
- // dont have focus. In these cases we do not adjust explorer selection for non-focussed editors
+ // don't have focus. In these cases we do not adjust explorer selection for non-focused editors
// because we only want to react for the editor that has focus.
if (!this.partService.isCreated() && e.editorOptions && e.editorOptions.preserveFocus) {
@@ -198,10 +198,10 @@ export class ExplorerView extends CollapsibleViewletView {
public focus(): void {
super.focus();
- // Open the focussed element in the editor if there is currently no file opened
+ // Open the focused element in the editor if there is currently no file opened
let input = this.editorService.getActiveEditorInput();
if (!input || !(input instanceof FileEditorInput)) {